@@ -1619,20 +1619,32 @@ void qjackctlGraphCanvas::mousePressEvent ( QMouseEvent *event )
 	m_item = nullptr;
 	m_pos = QGraphicsView::mapToScene(event->pos());
 
-	qjackctlGraphItem *item = itemAt(m_pos);
-	if (item && item->type() >= QGraphicsItem::UserType)
-		m_item = static_cast<qjackctlGraphItem *> (item);
-
-	if (event->button() == Qt::LeftButton ||
-		event->button() == Qt::MiddleButton)
+	if (event->button() == Qt::LeftButton) {
+		m_item = itemAt(m_pos);
 		m_state = DragStart;
+	}
 
-	if (m_state == DragStart && m_item == nullptr
+	if (m_item == nullptr
 		&& (((event->button() == Qt::LeftButton)
 		  && (event->modifiers() & Qt::ControlModifier))
 		  || (event->button() == Qt::MiddleButton))
 		&& m_scene->selectedItems().isEmpty()) {
-		QGraphicsView::setCursor(Qt::ClosedHandCursor);
+	#if 1//NEW_DRAG_SCROLL_MODE
+		// HACK: When about to drag-scroll,
+		// always fake a left-button press...
+		QGraphicsView::setDragMode(ScrollHandDrag);
+		QMouseEvent event2(event->type(),
+		#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+			event->position(), event->globalPosition(),
+		#else
+			event->localPos(), event->globalPos(),
+		#endif
+			Qt::LeftButton, Qt::LeftButton,
+			event->modifiers() | Qt::ControlModifier);
+		QGraphicsView::mousePressEvent(&event2);
+	#else
+		QGraphicsView::setCursor(Qt::ClosedHandCursor)
+	#endif
 		m_state = DragScroll;
 	}
 }
@@ -1781,12 +1793,16 @@ void qjackctlGraphCanvas::mouseMoveEvent ( QMouseEvent *event )
 		}
 		break;
 	case DragScroll: {
+	#if 1//NEW_DRAG_SCROLL_MODE
+		QGraphicsView::mouseMoveEvent(event);
+	#else
 		QScrollBar *hbar = QGraphicsView::horizontalScrollBar();
 		QScrollBar *vbar = QGraphicsView::verticalScrollBar();
 		const QPoint delta = (pos - m_pos).toPoint();
 		hbar->setValue(hbar->value() - delta.x());
 		vbar->setValue(vbar->value() - delta.y());
 		m_pos = pos;
+	#endif
 		break;
 	}
 	default:
@@ -1900,6 +1916,12 @@ void qjackctlGraphCanvas::mouseReleaseEvent ( QMouseEvent *event )
 		break;
 	}
 
+#if 1//NEW_DRAG_SCROLL_MODE
+	if (QGraphicsView::dragMode() == ScrollHandDrag) {
+		QGraphicsView::mouseReleaseEvent(event);
+		QGraphicsView::setDragMode(NoDrag);
+	}
+#endif
 	m_state = DragNone;
 	m_item = nullptr;
 
