@@ -1,7 +1,7 @@
 // qjackctlGraph.h
 //
 /****************************************************************************
-   Copyright (C) 2003-2022, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2023, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -32,6 +32,9 @@
 #include <QList>
 #include <QHash>
 
+class QGestureEvent;
+class QPinchGesture;
+
 
 // Forward decls.
 class qjackctlGraphCanvas;
@@ -543,6 +546,9 @@ public:
 	void setAliases(qjackctlAliases *aliases);
 	qjackctlAliases *aliases() const;
 
+	// Snap into position helper.
+	QPointF snapPos(qreal x, qreal y) const;
+
 signals:
 
 	// Node factory notifications.
@@ -614,6 +620,11 @@ protected:
 	// Keyboard event handler.
 	void keyPressEvent(QKeyEvent *event);
 
+	// Gesture event handlers.
+	bool event(QEvent *event);
+	bool gestureEvent(QGestureEvent *event);
+	void pinchGesture(QPinchGesture *pinch);
+
 	// Graph node key helper.
 	QString nodeKey(qjackctlGraphNode *node) const;
 
@@ -627,6 +638,13 @@ protected:
 	// Renaming editor position and size updater.
 	void updateEditorGeometry();
 
+	// Bounding margins/limits...
+	const QRectF& boundingRect(bool reset = false);
+	void boundingPos(QPointF& pos);
+
+	// Snap into position helper.
+	void snapPos(QPointF& pos) const;
+
 private:
 
 	// Mouse pointer dragging states.
@@ -641,6 +659,7 @@ private:
 	QRubberBand          *m_rubberband;
 	qreal                 m_zoom;
 	bool                  m_zoomrange;
+	bool                  m_gesture;
 
 	qjackctlGraphNode::ItemKeys m_nodekeys;
 	QList<qjackctlGraphNode *>  m_nodes;
